==> haskell-djot-0.1.1.3-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 djot
version:              0.1.1.3
visibility:           public
id:                   djot-0.1.1.3-74eL9NXyy53Ae1DGywguZU
key:                  djot-0.1.1.3-74eL9NXyy53Ae1DGywguZU
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  f74ab3e5cb3ead19a721e61620ea6fc0
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.1.3-74eL9NXyy53Ae1DGywguZU
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    doclayout-0.4.0.1-9J1mS0pktDuJcWoNNHYW1p mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djot-0.1.1.3-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djot.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 djot
version:              0.1.1.3
visibility:           public
id:                   djot-0.1.1.3-JNmcKO4oNJtDRcrUMlAfzT
key:                  djot-0.1.1.3-JNmcKO4oNJtDRcrUMlAfzT
license:              MIT
copyright:            Copyright (C) 2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parser and renderer for djot light markup syntax.
description:
    Djot (<https://djot.net>) is a light markup language.
    This package provides a data structure to represent
    djot documents, a very fast parser, and functions
    to render a parsed document as HTML and as djot.

category:             Text
abi:                  e19b97120f0de7037d52c46ec84b6946
exposed:              True
exposed-modules:
    Djot Djot.AST Djot.Attributes Djot.Blocks Djot.Djot Djot.Html
    Djot.Inlines Djot.Options Djot.Parse

import-dirs:          /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/djot-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-djot
hs-libraries:         HSdjot-0.1.1.3-JNmcKO4oNJtDRcrUMlAfzT
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    doclayout-0.4.0.1-JhhFAgNLi9YEWEfw5R1V9v mtl-2.2.2 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-djot/html/djot.haddock
haddock-html:         /usr/share/doc/haskell-djot/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
